@@ -1,15 +1,15 @@
 #!/bin/sh
 echo 'name: text
-version: 0.11.0.6
-id: text-0.11.0.6-ace87dcbd28176f4bf784c8b8e080ab9
+version: 0.11.1.5
+id: text-0.11.1.5-24dbc1ca0a1252804bf8bef893d5cf9c
 
 license: BSD3
-copyright: 2008-2009 Tom Harper, 2009-2010 Bryan O'\''Sullivan
+copyright: 2009-2011 Bryan O'\''Sullivan, 2008-2009 Tom Harper
 maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
             Tom Harper <rtomharper@googlemail.com>
             Duncan Coutts <duncan@haskell.org>
 stability:
-homepage: http://bitbucket.org/bos/text
+homepage: https://bitbucket.org/bos/text
 package-url:
 description: .
              An efficient packed, immutable Unicode text type (both strict and
@@ -44,6 +44,7 @@ exposed: True
 exposed-modules: Data.Text Data.Text.Array Data.Text.Encoding
                  Data.Text.Encoding.Error Data.Text.Foreign Data.Text.IO
                  Data.Text.Internal Data.Text.Lazy Data.Text.Lazy.Builder
+                 Data.Text.Lazy.Builder.Int Data.Text.Lazy.Builder.RealFloat
                  Data.Text.Lazy.Encoding Data.Text.Lazy.IO Data.Text.Lazy.Internal
                  Data.Text.Lazy.Read Data.Text.Read
 hidden-modules: Data.Text.Encoding.Fusion
@@ -51,26 +52,30 @@ hidden-modules: Data.Text.Encoding.Fusion
                 Data.Text.Encoding.Utf32 Data.Text.Encoding.Utf8 Data.Text.Fusion
                 Data.Text.Fusion.CaseMapping Data.Text.Fusion.Common
                 Data.Text.Fusion.Internal Data.Text.Fusion.Size
-                Data.Text.IO.Internal Data.Text.Lazy.Encoding.Fusion
-                Data.Text.Lazy.Fusion Data.Text.Lazy.Search Data.Text.Search
-                Data.Text.Unsafe Data.Text.UnsafeChar Data.Text.UnsafeShift
+                Data.Text.IO.Internal Data.Text.Lazy.Builder.Functions
+                Data.Text.Lazy.Builder.RealFloat.Functions
+                Data.Text.Lazy.Encoding.Fusion Data.Text.Lazy.Fusion
+                Data.Text.Lazy.Search Data.Text.Search Data.Text.Unsafe
+                Data.Text.Unsafe.Base Data.Text.UnsafeChar Data.Text.UnsafeShift
                 Data.Text.Util
-import-dirs: /usr/local/lib/ghc/text-0.11.0.6
-library-dirs: /usr/local/lib/ghc/text-0.11.0.6
-hs-libraries: HStext-0.11.0.6
+import-dirs: /usr/local/lib/ghc/text-0.11.1.5
+library-dirs: /usr/local/lib/ghc/text-0.11.1.5
+hs-libraries: HStext-0.11.1.5
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-912d55d387093f740e3bcd2ffbf1dd83
-         bytestring-0.9.1.10-e7cebdd905566e960c42140389871ec1
-         deepseq-1.1.0.2-09b3aed0c4982bbc6569c668100876fa
-         ghc-prim-0.2.0.0-6bf7b03ebc9c668817e4379b6796c0c2
+depends: array-0.3.0.2-143060371bda4ff52c270d1067551fe8
+         base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
+         bytestring-0.9.1.10-d11caeadd9605139e1a59850ce083826
+         deepseq-1.1.0.2-0465f803f7d27d264907e7e03e72a71f
+         ghc-prim-0.2.0.0-d9df11f804556f362beb0ea4e67261ba
+         integer-gmp-0.2.0.3-298c59ba68b7aaa7e76ae5b1fe5e876e
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-text-0.11.0.6/html/text.haddock
-haddock-html: /usr/local/share/doc/hs-text-0.11.0.6/html
+haddock-interfaces: /usr/local/share/doc/hs-text-0.11.1.5/html/text.haddock
+haddock-html: /usr/local/share/doc/hs-text-0.11.1.5/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
